; $Id: plotmonth1996.pro,v 1.2 1998/03/09 18:05:45 rgr Exp $

; $RCSfile: plotmonth1996.pro,v $
; $Author: rgr $
; $Date: 1998/03/09 18:05:45 $
; $Revision: 1.2 $

pro PlotMonth1996, second1996,                                     $
                   value,                                          $
                   XRANGE=xrange,                                  $
                   _EXTRA=extra

   nvalue = n_elements(value)

   ;  Set the range of the X-axis.

   if (not keyword_set(xrange)) then begin
      time0 = CvtFromSec1996(second1996(0))
      time0.hour = 0L
      time0.min = 0L
      time0.sec = 0L
      time1 = CvtFromSec1996(second1996(nvalue-1) + 86400 - 1)
      time1.hour = 0L
      time1.min = 0L
      time1.sec = 0L
      xrange = [CvtToSec1996(time0), CvtToSec1996(time1)]
   endif
   xoffset = long(xrange(0))

   ; Get a smooth data set to establish the range of the Y-axis;

   index = where(value ne 0, count)
   case count of
      0: begin
            vmedian = [0.0, 0.0]
            smedian = [xrange(0), xrange(1)]
         end
      1: begin
            vmedian = [value(index[0]), 0.1*value(index[0])]
            smedian = [xrange(0), xrange(1)]
         end
      2: begin
            vmedian = value(index)
            smedian = second1996(index)
         end
   ELSE: begin
            vmedian = median(value(index), 3)
            smedian = second1996(index)
         end
   endcase

   ; If the variable being plotted is a status variable, i.e it can
   ; only assume the values 0 and 1, then adjust the range of the 
   ; Y-axis so both states are visible.

   index = where((value ne 0) and (value ne 1), count)
   if (count eq 0) then begin
      vmedian = [-0.1, 1.1]
      smedian = [xrange(0), xrange(1)]
   endif

   ; Compute the number of major and minor ticks on the X-axis, 
   ; the locations of the major ticks on the X-axis, and the labels
   ; for the major ticks.

   mdays = [1, 2, 3, 4, 5, 10, 15, 30, 60, 60, 120, 180, 360]
   time0 = CvtFromSec1996(xrange(0))
   time0.hour = 0L
   time0.min  = 0L
   time0.sec = 0L
   xday0 = CvtToSec1996(time0)
   nday = (xrange(1) - xday0) / 86400
   xday = xday0 + 86400 * lindgen(nday + 1)
   index = where((xrange(0) le xday) and (xday le xrange(1)), count)
   set = where(count/mdays le 6) 
   mday = mdays(set(0))
   ntick = count - 1
   if (ntick gt 0) then begin
      time = CvtFromSec1996(xday(index) + (86400/2))
      day = time.day
      daymin = min(day)
      index = where(day eq daymin)
      time(index(0)).hour = 0L
      time(index(0)).min = 0L
      time(index(0)).sec = 0L
      xtick0 = CvtToSec1996(time(index(0))) - (index(0)/mday) * 86400
      ntick = (xrange(1) - xtick0) / (mday * 84000)
      xtickv = xtick0 + (mday * 86400 * lindgen(ntick+1))
      time = CvtFromSec1996(xtickv + (86400/2))
      xticklab = time.day
      xtickname = strtrim(string(xticklab), 2)
   endif else begin
      ntick = 1
      xtickv = xrange
      time = CvtFromSec1996(xrange)
      seconds = 3600*time.hour + 60*time.min + time.sec
      xticklab = float(time.day) + float(seconds)/86400.0
      xtickname = strtrim(string(format='(f8.2)', xticklab), 2)
   endelse
   
   ; Draw the empty plotting area.

   date0 = StringDate1996(xrange(0))
   date1 = StringDate1996(xrange(1))
   subtitle = date0 + '  to  ' + date1
   xminor = mday
   if (xminor le 2) then xminor = 4
   plot, /nodata, smedian - xoffset, vmedian, _EXTRA=extra,       $
         YSTYLE=16, XRANGE = xrange - xoffset, XTICKS=ntick,      $
         XTICKV=xtickv - xoffset, XTICKNAME=xtickname,            $
         XMINOR = xminor, Xtitle='Day of Month', SUBTITLE=subtitle

   ; Break the data into groups of contiguous data
   
   diff = second1996(1:nvalue-1) - second1996(0:nvalue-2)
   delta = median(diff)
   index = where(diff gt 1.5*delta, count)
   if (count gt 0) then begin
      ngroup = count+1
      group=lonarr(2,ngroup)
      group(0, 0) = 0L
      group(0, 1:ngroup-1) = index + 1L
      group(1, 0:ngroup-2) = index
      group(1, ngroup-1) = nvalue-1
   endif else begin
      ngroup = 1
      group=lonarr(2,1)
      group(0, 0) = 0L
      group(1, 0) = nvalue-1
   endelse
   delta = long(delta + 0.5)

   ; Plot each group of data
 
   for i=0, ngroup-1 do begin
      npt = group(1, i) - group(0,i) + 1
      sec = lonarr(2, npt, /nozero)
      val = fltarr(2, npt, /nozero)
      sec(0,*) = second1996(group(0,i) : group(1,i))
      sec(1,*) = sec(0,*) + delta
      val(0,*) = value(group(0,i) : group(1,i))
      val(1,*) = val(0,*)
      sec = reform(sec, 2*npt, /overwrite)
      val = reform(val, 2*npt, /overwrite)
      oplot, sec - xoffset, val, _EXTRA=extra
   endfor

end
