; $Id: uncompresssisvalue.pro,v 1.1 1998/01/26 17:57:06 rgr Exp $

; $RCSfile: uncompresssisvalue.pro,v $
; $Author: rgr $
; $Date: 1998/01/26 17:57:06 $
; $Revision: 1.1 $

; UncompressSisValue
;
; This function uncompresses the counters that are used to calculate
; rates for the SIS instrument.  The counter values are always
; non-negative integers.  For counter values less than or equal to
; 4096, the compressed value and the uncompressed are identical.
; For values greater than 4096, the values are stored as an 11 bit
; fraction with an implicit one and a 4-bit exponent with bias 
; of 1.
;
; When uncompressing the values greater than 4096, this function
; forms a thirteen bit fraction by changing the implicit one into
; an explicit one, shifting the fraction to the left by one, and
; setting the least significant bit to one.  To compensate for the
; the left shift of the fraction, the bias is increased by one.
;
; Arguments
;    val = compressed SIS counter value - input

function UncompressSisValue, val

value = long(val)
index = where((value ge 4096), ncount)
if (ncount eq 0) then return, float(value)

exponent = ishft(value(index), -11) - 2
value(index) = ishft((value(index) and '000007FF'XL), 1) or '00001001'XL
value(index) = ishft(value(index), exponent)
value = float(value)
value(index) = value(index) - 0.5
return, value
end
